# swagger-java-client

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>io.swagger</groupId>
    <artifactId>swagger-java-client</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/swagger-java-client-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.CustomerApi;

import java.io.File;
import java.util.*;

public class CustomerApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();
        
        // Configure API key authorization: api_key
        ApiKeyAuth api_key = (ApiKeyAuth) defaultClient.getAuthentication("api_key");
        api_key.setApiKey("YOUR API KEY");
        // Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
        //api_key.setApiKeyPrefix("Token");

        CustomerApi apiInstance = new CustomerApi();
        String companyid = "companyid_example"; // String | Company ID
        String firstname = "firstname_example"; // String | Customer First Name
        String lastname = "lastname_example"; // String | Customer Last Name
        String sendtype = "1"; // String | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\" 
        String email = "email_example"; // String | Customer Email
        String mobile = "mobile_example"; // String | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input 
        String address = "address_example"; // String | Customer Postal Address
        String zipcode = "zipcode_example"; // String | Customer Zipcode
        String city = "city_example"; // String | Customer City
        String state = "state_example"; // String | Customer State / Province / Region
        String country = "country_example"; // String | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt 
        String language = "language_example"; // String | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages 
        String notes = "notes_example"; // String | Additional Customer Notes
        try {
            String result = apiInstance.createCustomerAutomatic(companyid, firstname, lastname, sendtype, email, mobile, address, zipcode, city, state, country, language, notes);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling CustomerApi#createCustomerAutomatic");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://reputationcrm.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomerApi* | [**createCustomerAutomatic**](docs/CustomerApi.md#createCustomerAutomatic) | **POST** /createCustomerAutomatic | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)
*CustomerApi* | [**createCustomerAutomaticWithDelayReviewRequest**](docs/CustomerApi.md#createCustomerAutomaticWithDelayReviewRequest) | **POST** /createCustomerAutomaticWithDelayReviewRequest | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)
*CustomerApi* | [**createCustomerImmediateFirstReviewRequest**](docs/CustomerApi.md#createCustomerImmediateFirstReviewRequest) | **POST** /createCustomerImmediateFirstReviewRequest | Create a Customer AND Feedback / Review Requests
*CustomerApi* | [**createCustomerManualScheduleOneReviewRequest**](docs/CustomerApi.md#createCustomerManualScheduleOneReviewRequest) | **POST** /createCustomerManualScheduleOneReviewRequest | Create a Customer AND a one Feedback / Review Request (Manual Scheduling)
*CustomerApi* | [**deleteCustomer**](docs/CustomerApi.md#deleteCustomer) | **DELETE** /deleteCustomer | Delete ONE Customer record
*CustomerApi* | [**getAllCustomersBycompanyId**](docs/CustomerApi.md#getAllCustomersBycompanyId) | **GET** /getAllCustomersBycompanyId | Get Information on ALL Customers of a Company / Location / Feedback Page
*CustomerApi* | [**getCustomersWhoHaveNotYetSubmittedReview**](docs/CustomerApi.md#getCustomersWhoHaveNotYetSubmittedReview) | **GET** /getCustomersWhoHaveNotYetSubmittedReview | Get a list of Customers who have not yet submitted their Review / Feedback
*CustomerApi* | [**getSingleCustomer**](docs/CustomerApi.md#getSingleCustomer) | **GET** /getSingleCustomer | Get Information of ONE Customer
*CustomerApi* | [**updateCustomer**](docs/CustomerApi.md#updateCustomer) | **PUT** /updateCustomer | Update the record of ONE Customer
*EmailSmsStatsApi* | [**getEmailSmsSentCount**](docs/EmailSmsStatsApi.md#getEmailSmsSentCount) | **GET** /getEmailSmsSentCount | Email / SMS sent
*EmailSmsStatsApi* | [**getEmailSmsSentLimit**](docs/EmailSmsStatsApi.md#getEmailSmsSentLimit) | **GET** /getEmailSmsSentLimit | Email / SMS Limit
*QueueApi* | [**deleteQueueByCustomerId**](docs/QueueApi.md#deleteQueueByCustomerId) | **DELETE** /deleteQueueByCustomerId | Delete requests of a customer
*QueueApi* | [**deleteQueueBycompanyId**](docs/QueueApi.md#deleteQueueBycompanyId) | **DELETE** /deleteQueueBycompanyId | Delete requests of a company
*QueueApi* | [**getQueueBycompanyId**](docs/QueueApi.md#getQueueBycompanyId) | **GET** /getQueueBycompanyId | Get a customerâ€™s queue
*QueueApi* | [**getSingleCustomerQueue**](docs/QueueApi.md#getSingleCustomerQueue) | **GET** /getQueueByCustomerId | Get a customerâ€™s queue
*RescheduleApi* | [**rescheduleCustomerAutomatic**](docs/RescheduleApi.md#rescheduleCustomerAutomatic) | **POST** /rescheduleCustomerAutomatic | Reschedule Customer (Automatic)
*RescheduleApi* | [**rescheduleCustomerImmediate**](docs/RescheduleApi.md#rescheduleCustomerImmediate) | **POST** /rescheduleCustomerImmediate | Reschedule Customer (Send right away)
*RescheduleApi* | [**rescheduleManualOneReviewRequest**](docs/RescheduleApi.md#rescheduleManualOneReviewRequest) | **POST** /rescheduleManualOneReviewRequest | Reschedule Customer (Manual Schedule)
*ReviewSitesApi* | [**getAllReviewSitesByUserName**](docs/ReviewSitesApi.md#getAllReviewSitesByUserName) | **GET** /getAllReviewSitesByUserName | Get all review sites of an account
*ReviewSitesApi* | [**getAllReviewSitesBycompanyId**](docs/ReviewSitesApi.md#getAllReviewSitesBycompanyId) | **GET** /getAllReviewSitesBycompanyId | Get all review sites of a company
*ReviewsApi* | [**getCommentsonReview**](docs/ReviewsApi.md#getCommentsonReview) | **GET** /getCommentsonReview | Get review comments
*ReviewsApi* | [**getReviewsByCompanyID**](docs/ReviewsApi.md#getReviewsByCompanyID) | **GET** /getReviewsByCompanyID | Get X last reviews less than X days old of a company
*ReviewsApi* | [**getReviewsByCompanyIDAndReviewSite**](docs/ReviewsApi.md#getReviewsByCompanyIDAndReviewSite) | **GET** /getReviewsByCompanyIDAndReviewSite | Get X last reviews less than X days old of a review site of a company
*ReviewsApi* | [**getReviewsByCompanyIDRatingAndReviewSite**](docs/ReviewsApi.md#getReviewsByCompanyIDRatingAndReviewSite) | **GET** /getReviewsByCompanyIDRatingAndReviewSite | Get X last reviews that equal or over X stars of a review site of a company
*ReviewsApi* | [**getReviewsByCompanyIdAndRating**](docs/ReviewsApi.md#getReviewsByCompanyIdAndRating) | **GET** /getReviewsByCompanyIdAndRating | Get X last reviews that equal or over X stars of a company
*ReviewsApi* | [**getReviewsByUserName**](docs/ReviewsApi.md#getReviewsByUserName) | **GET** /getReviewsByUserName | Get X last reviews less than X days old of an account
*ReviewsApi* | [**getReviewsByUserNameAndRating**](docs/ReviewsApi.md#getReviewsByUserNameAndRating) | **GET** /getReviewsByUserNameAndRating | Get X last reviews that equal or over X stars of an account
*ReviewsApi* | [**getReviewsByUserNameAndReviewSite**](docs/ReviewsApi.md#getReviewsByUserNameAndReviewSite) | **GET** /getReviewsByUserNameAndReviewSite | Get X last reviews less than X days old of a review site of an account
*ReviewsApi* | [**getReviewsByUserNameRatingAndReviewSite**](docs/ReviewsApi.md#getReviewsByUserNameRatingAndReviewSite) | **GET** /getReviewsByUserNameRatingAndReviewSite | Get X last reviews that equal or over X stars of a review site of an account
*ReviewsApi* | [**postCommentOnReview**](docs/ReviewsApi.md#postCommentOnReview) | **POST** /postCommentOnReview | Comment on a Feedback / Review
*ReviewsStatsApi* | [**getNumberOfReviewsPostedInLastDaysByCompanyId**](docs/ReviewsStatsApi.md#getNumberOfReviewsPostedInLastDaysByCompanyId) | **GET** /getNumberOfReviewsPostedInLastDaysByCompanyId | Get total reviews received for each review site
*ReviewsStatsApi* | [**getNumberOfReviewsRequiredToAchieve5StarByCompanyId**](docs/ReviewsStatsApi.md#getNumberOfReviewsRequiredToAchieve5StarByCompanyId) | **GET** /getNumberOfReviewsRequiredToAchieve5StarByCompanyId | Get for ALL Review Sites the number of 5-star Feedback / Reviews needed to achieve a 5-star Customer Experience 
*ReviewsStatsApi* | [**getOverallRatingAndReviewCountForPlatformReviewsByCompanyId**](docs/ReviewsStatsApi.md#getOverallRatingAndReviewCountForPlatformReviewsByCompanyId) | **GET** /getOverallRatingAndReviewCountForPlatformReviewsByCompanyId | Get The Overall Rating and Total Review Count of a Company / Location for platform collected reviews  
*ReviewsStatsApi* | [**getOverallRatingForEachReviewSiteByCompanyId**](docs/ReviewsStatsApi.md#getOverallRatingForEachReviewSiteByCompanyId) | **GET** /getOverallRatingForEachReviewSiteByCompanyId | Get overall rating for each review site
*ReviewsStatsApi* | [**getOverallRatingOfCompanyByCompanyId**](docs/ReviewsStatsApi.md#getOverallRatingOfCompanyByCompanyId) | **GET** /getOverallRatingOfCompanyByCompanyId | Get The Overall Rating of a Company / Location / Feedback Page 
*ReviewsStatsApi* | [**getOverallReputationChangeOfAllReviewSitesByCompanyId**](docs/ReviewsStatsApi.md#getOverallReputationChangeOfAllReviewSitesByCompanyId) | **GET** /getOverallReputationChangeOfAllReviewSitesByCompanyId | Get the Overall Reputation Increase / Decrease of ALL Review Sites 
*ReviewsStatsApi* | [**getTotalReviewsReceivedForEachReviewSiteByCompanyId**](docs/ReviewsStatsApi.md#getTotalReviewsReceivedForEachReviewSiteByCompanyId) | **GET** /getTotalReviewsReceivedForEachReviewSiteByCompanyId | Get total reviews received for each review site
*SentLogApi* | [**getSentLogByCompanyId**](docs/SentLogApi.md#getSentLogByCompanyId) | **GET** /getSentLogByCompanyId | Get company&#39;s sent log
*SentLogApi* | [**getSentLogByCustomerId**](docs/SentLogApi.md#getSentLogByCustomerId) | **GET** /getSentLogByCustomerId | Get a customerâ€™s sent log


## Documentation for Models

 - [Comment](docs/Comment.md)
 - [Customer](docs/Customer.md)
 - [CustomerWhoHaveNotResponded](docs/CustomerWhoHaveNotResponded.md)
 - [EmailSmsSentCount](docs/EmailSmsSentCount.md)
 - [EmailSmsSentLimit](docs/EmailSmsSentLimit.md)
 - [Error](docs/Error.md)
 - [OverallCompanyRating](docs/OverallCompanyRating.md)
 - [OverallRatingAndReviewCount](docs/OverallRatingAndReviewCount.md)
 - [Queue](docs/Queue.md)
 - [Review](docs/Review.md)
 - [ReviewSites](docs/ReviewSites.md)
 - [ReviewSitesRating](docs/ReviewSitesRating.md)
 - [ReviewSitesReputationChange](docs/ReviewSitesReputationChange.md)
 - [ReviewSitesReviewCount](docs/ReviewSitesReviewCount.md)
 - [SentLog](docs/SentLog.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### api_key

- **Type**: API key
- **API key parameter name**: key
- **Location**: HTTP header


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

support@reputationcrm.com

